# 介绍
从它的名字就可以看出，这就是一个简单但很实用的模块
<br/>模块更新日志请使用log()命令来查看
# 迈出第一步
```Python
  import easy_functions as ef
  ef.help()
```
此操作将会显示命令列表和一些其他的帮助
<br/>如果你想直接获得纯净的命令列表，可以使用easy_functions.cmdlist
# 最后
如果对本模块有建议一定要告诉我啊，我也是第一次写模块
<br/>请在GitHub反馈问题